//+------------------------------------------------------------------+
//|                                                                  |
//|                       NVO Histogram.mq4                          |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2010 traderathome"
#property link      "email:   traderathome@msn.com"
/*--------------------------------------------------------------------
NVO Histogram:

This indicator creates an oscillating histogram of bars representing
the count of trades for each time frame interval. Bars with below 
average trade counts are shown below the zero line and bars with 
above average trade counts are shown above the zero line.  Bars are
color coded based upon the percent range of the average trade count 
they fall into.  

The average trade count is the avergae number of trades per bar for
the averaging period selected.  Percent ranges for color coding the
bars is accomplished using two numbers, "33" and "66" which creates 
four graduations:  0%-99% of normal, 100%-133% of normal, 133%-166% 
of normal, 166%-200% of normal and 200+% of normal.  

This indicator is based upon core code from the indicator that is
acknowleged below.  This code has been modified to remove the source
of errors logged by MT4 when running that indicator. 
                                                      - Traderathome
----------------------------------------------------------------------
Acknowledgements:
Vadim Shumiloff, shumiloff@mail.ru, Normalized Volume Oscillator.mq4
----------------------------------------------------------------------
Suggested Settings:   White Chart    Black Chart

Indicator Color 1     SlateBlue      DarkSlateBlue   0-99% average
Indicator Color 2     C'0,200,0'     Green           100-133% average
Indicator Color 3     Lime           LimeGreen       133-166% average 
Indicator Color 4     C'255,128,0'   Yellow          166-200% average
Indicator Color 5     Magenta        WhiteSmoke      200+% average
Indicator Color 6     SlateBlue      DarkSlateBlue   ZeroLine
---------------------------------------------------------------------*/

#property indicator_separate_window
#property indicator_buffers 6
#property indicator_color1  SlateBlue      // 0-99% average
#property indicator_color2  C'0,200,0'     // 100-133% average
#property indicator_color3  Lime           // 133-166% average 
#property indicator_color4  C'255,128,0'   // 166-200% average
#property indicator_color5  Magenta        // 200+% average
#property indicator_color6  SlateBlue      // ZeroLine

#property indicator_width1 2  
#property indicator_width2 2  
#property indicator_width3 2  
#property indicator_width4 2  
#property indicator_width5 2  
#property indicator_width6 1 

//---- Global External Inputs
extern bool  Indicator_ON     = true;
extern int   AveragingPeriod  = 10;

//---- Global Buffers & Other Inputs
double BufferH1[];
double BufferH2[];
double BufferH3[];
double BufferH4[];
double BufferH5[];
double ZeroLine[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{  
   SetIndexBuffer(0, BufferH1);
   SetIndexStyle(0, DRAW_HISTOGRAM);

   SetIndexBuffer(1, BufferH2);
   SetIndexStyle(1, DRAW_HISTOGRAM);
  
   SetIndexBuffer(2, BufferH3);
   SetIndexStyle(2, DRAW_HISTOGRAM);

   SetIndexBuffer(3, BufferH4);
   SetIndexStyle(3, DRAW_HISTOGRAM);

   SetIndexBuffer(4, BufferH5);
   SetIndexStyle(4, DRAW_HISTOGRAM);

   SetIndexStyle(5,DRAW_LINE);
   SetIndexBuffer(5,ZeroLine);

   //string short_name="NVO Histogram  (" + AveragingPeriod + ")   ";
   string short_name="NVO Histogram, Period " + AveragingPeriod;   
   //if (!Indicator_On)short_name=("NVO Histogram  ("+AveragingPeriod+")  -Off.   ");
   if (!Indicator_ON)short_name=("NVO Histogram, Perioid "+AveragingPeriod+"  -Off.   ");      
   IndicatorShortName(short_name);
   SetIndexLabel(0, NULL);
   SetIndexLabel(0, NULL);
   SetIndexLabel(1, NULL);
   SetIndexLabel(2, NULL);
   SetIndexLabel(3, NULL);
   SetIndexLabel(4, NULL);
   SetIndexLabel(5, NULL);
   return(0);
}
  
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{       
   return(0);
}

//+------------------------------------------------------------------+
//| Calculations body of program                                     |                                                        
//+------------------------------------------------------------------+  
int start()
{
   deinit(); if (!Indicator_ON) {return(0);}
   int counted_bars = IndicatorCounted();

   if (counted_bars < 1)
      for (int i = 1; i <= AveragingPeriod; i++) 
      {
         BufferH1[Bars-i] = 0;
         BufferH2[Bars-i] = 0;
         BufferH3[Bars-i] = 0;
         BufferH4[Bars-i] = 0;
         BufferH5[Bars-i] = 0;
      }

   int limit = Bars - counted_bars;
   if (counted_bars > 0) limit++;
   double ntc = 0;
   
   for(i = 0; i < limit; i++)
   {
      BufferH1[i] = 0;
      BufferH2[i] = 0;
      BufferH3[i] = 0;
      BufferH4[i] = 0;
      BufferH5[i] = 0;
      ZeroLine[i] = 0;
      
      ntc = NormalizedTradeCount(i)*100 - 100;
      
      if (ntc < 0)
      {
         BufferH1[i] = ntc;
      }
      else
      {
         if (ntc < 33)
         {
            BufferH2[i] = ntc;
         }
         else
         {
            if (ntc < 67)
            {
               BufferH3[i] = ntc;
            }
            else
            {
               if (ntc < 100)
               {
                  BufferH4[i] = ntc;
               }
               else BufferH5[i] = ntc;
            }
         }
      }
   }
   
   return(0);
}
   
//+-------------------------------------------------------------------+
//| Subroutine to compute normalized volume                           |                                                        
//+-------------------------------------------------------------------+
double NormalizedTradeCount(int i)
{
   double nt = 0;
   for (int j = i; j < (i+AveragingPeriod); j++) nt = nt + Volume[j];
   nt = nt / AveragingPeriod;
   return (Volume[i] / nt);
}
     
//+-------------------------------------------------------------------+
//| End of program                                                    |                                                        
//+-------------------------------------------------------------------


